Index: Application/Riskeer/src/Application.Riskeer/App.xaml.cs
===================================================================
diff -u -rcb6d0d0e0260d373f0ade513d28e6ffcfc28a138 -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Application/Riskeer/src/Application.Riskeer/App.xaml.cs (.../App.xaml.cs) (revision cb6d0d0e0260d373f0ade513d28e6ffcfc28a138)
+++ Application/Riskeer/src/Application.Riskeer/App.xaml.cs (.../App.xaml.cs) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -203,7 +203,7 @@
}
///
- /// app.config has been configured to use
+ /// app.config has been configured to use
/// to write log files to the Riskeer user data folder. This method deletes the old log files
/// that have been written there.
///
Index: Application/Riskeer/src/Application.Riskeer/app.config
===================================================================
diff -u -rcb6d0d0e0260d373f0ade513d28e6ffcfc28a138 -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Application/Riskeer/src/Application.Riskeer/app.config (.../app.config) (revision cb6d0d0e0260d373f0ade513d28e6ffcfc28a138)
+++ Application/Riskeer/src/Application.Riskeer/app.config (.../app.config) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -46,7 +46,7 @@
-
+
Index: Core/Common/src/Core.Common.Base/Storage/IMigrateProject.cs
===================================================================
diff -u -r6cdb90fc3f89fe0c44b62d3be7266a0090a6b891 -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Core/Common/src/Core.Common.Base/Storage/IMigrateProject.cs (.../IMigrateProject.cs) (revision 6cdb90fc3f89fe0c44b62d3be7266a0090a6b891)
+++ Core/Common/src/Core.Common.Base/Storage/IMigrateProject.cs (.../IMigrateProject.cs) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -44,8 +44,8 @@
MigrationRequired ShouldMigrate(string filePath);
///
- /// Determines the target file path to place the migrated Ringtoets project based
- /// on it's original file path.
+ /// Determines the target file path to place the migrated project based
+ /// on its original file path.
///
/// The file path to be used as location for the migration result. Value
/// will be null if no target file path can be provided.
Index: Core/Common/src/Core.Common.Base/Storage/MigrationRequired.cs
===================================================================
diff -u -r6cdb90fc3f89fe0c44b62d3be7266a0090a6b891 -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Core/Common/src/Core.Common.Base/Storage/MigrationRequired.cs (.../MigrationRequired.cs) (revision 6cdb90fc3f89fe0c44b62d3be7266a0090a6b891)
+++ Core/Common/src/Core.Common.Base/Storage/MigrationRequired.cs (.../MigrationRequired.cs) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -22,7 +22,7 @@
namespace Core.Common.Base.Storage
{
///
- /// Enum to indicate if migration of a Ringtoets project file is required or not.
+ /// Enum to indicate if migration of a project file is required or not.
///
public enum MigrationRequired
{
Fisheye: Tag 3882746b496b55f9c4ff66628a7e3f1f0fc22f81 refers to a dead (removed) revision in file `Core/Common/src/Core.Common.Gui/Appenders/RingtoetsUserDataFolderConverter.cs'.
Fisheye: No comparison available. Pass `N' to diff?
Index: Core/Common/src/Core.Common.Gui/Appenders/RiskeerUserDataFolderConverter.cs
===================================================================
diff -u
--- Core/Common/src/Core.Common.Gui/Appenders/RiskeerUserDataFolderConverter.cs (revision 0)
+++ Core/Common/src/Core.Common.Gui/Appenders/RiskeerUserDataFolderConverter.cs (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -0,0 +1,39 @@
+// Copyright (C) Stichting Deltares 2019. All rights reserved.
+//
+// This file is part of Riskeer.
+//
+// Riskeer is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System.IO;
+using Core.Common.Util.Settings;
+using log4net.Util;
+
+namespace Core.Common.Gui.Appenders
+{
+ ///
+ /// Converter that injects the application user data folder.
+ ///
+ public class RiskeerUserDataFolderConverter : PatternConverter // NOTE: Class might look like it's only used in tests, but it's actually created in Application.Riskeer/app.config!
+ {
+ protected override void Convert(TextWriter writer, object state)
+ {
+ string settingsDirectory = SettingsHelper.Instance.GetApplicationLocalUserSettingsDirectory(Option);
+ writer.Write(settingsDirectory);
+ }
+ }
+}
\ No newline at end of file
Index: Core/Common/src/Core.Common.Gui/Core.Common.Gui.csproj
===================================================================
diff -u -r9bba38e3ebe3fe261e7c97c338b016681e07c140 -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Core/Common/src/Core.Common.Gui/Core.Common.Gui.csproj (.../Core.Common.Gui.csproj) (revision 9bba38e3ebe3fe261e7c97c338b016681e07c140)
+++ Core/Common/src/Core.Common.Gui/Core.Common.Gui.csproj (.../Core.Common.Gui.csproj) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -30,7 +30,7 @@
-
+
Index: Core/Common/src/Core.Common.Gui/GuiCore.cs
===================================================================
diff -u -r6cdb90fc3f89fe0c44b62d3be7266a0090a6b891 -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Core/Common/src/Core.Common.Gui/GuiCore.cs (.../GuiCore.cs) (revision 6cdb90fc3f89fe0c44b62d3be7266a0090a6b891)
+++ Core/Common/src/Core.Common.Gui/GuiCore.cs (.../GuiCore.cs) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -89,7 +89,7 @@
isAlreadyRunningInstanceOfIGui = false; // reset to that the consecutive creations won't fail.
throw new InvalidOperationException(
string.Format(CultureInfo.CurrentCulture,
- Resources.GuiCore_Only_a_single_instance_of_Ringtoets_is_allowed_at_the_same_time_per_process_Make_sure_that_the_previous_instance_was_disposed_correctly_stack_trace_0,
+ Resources.GuiCore_Only_a_single_instance_of_Riskeer_is_allowed_at_the_same_time_per_process_Make_sure_that_the_previous_instance_was_disposed_correctly_stack_trace_0,
instanceCreationStackTrace));
}
Index: Core/Common/src/Core.Common.Gui/Properties/Resources.resx
===================================================================
diff -u -r1c63ed874ea711272be813b8bbf0eea00f0389b6 -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Core/Common/src/Core.Common.Gui/Properties/Resources.resx (.../Resources.resx) (revision 1c63ed874ea711272be813b8bbf0eea00f0389b6)
+++ Core/Common/src/Core.Common.Gui/Properties/Resources.resx (.../Resources.resx) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -268,8 +268,8 @@
..\Resources\information.png;System.Drawing.Bitmap, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
-
- Slechts één instantie van de Ringtoets grafische interface is toegestaan per proces. Zorg ervoor dat de vorige instantie correct opgeruimd is. 'Stack trace': {0}
+
+ Slechts één instantie van de Riskeer grafische interface is toegestaan per proces. Zorg ervoor dat de vorige instantie correct opgeruimd is. 'Stack trace': {0}
Log Tonen
@@ -302,10 +302,10 @@
Exporteren van '{0}' is gestart.
- Ringtoets kan de huidige selectie niet exporteren.
+ Riskeer kan de huidige selectie niet exporteren.
- Ringtoets kan de huidige selectie ({0}) niet exporteren.
+ Riskeer kan de huidige selectie ({0}) niet exporteren.
Versie
Fisheye: Tag 3882746b496b55f9c4ff66628a7e3f1f0fc22f81 refers to a dead (removed) revision in file `Core/Common/test/Core.Common.Gui.Test/Appenders/RingtoetsUserDataFolderConverterTest.cs'.
Fisheye: No comparison available. Pass `N' to diff?
Index: Core/Common/test/Core.Common.Gui.Test/Appenders/RiskeerUserDataFolderConverterTest.cs
===================================================================
diff -u
--- Core/Common/test/Core.Common.Gui.Test/Appenders/RiskeerUserDataFolderConverterTest.cs (revision 0)
+++ Core/Common/test/Core.Common.Gui.Test/Appenders/RiskeerUserDataFolderConverterTest.cs (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -0,0 +1,73 @@
+// Copyright (C) Stichting Deltares 2019. All rights reserved.
+//
+// This file is part of Riskeer.
+//
+// Riskeer is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System.IO;
+using Core.Common.Gui.Appenders;
+using Core.Common.Util.Settings;
+using log4net.Util;
+using NUnit.Framework;
+using Rhino.Mocks;
+
+namespace Core.Common.Gui.Test.Appenders
+{
+ [TestFixture]
+ public class RiskeerUserDataFolderConverterTest
+ {
+ [Test]
+ public void DefaultConstructor_ExpectedValues()
+ {
+ // Call
+ var converter = new RiskeerUserDataFolderConverter();
+
+ // Assert
+ Assert.IsInstanceOf(converter.FormattingInfo);
+ Assert.IsNull(converter.Next);
+ Assert.IsNull(converter.Option);
+ Assert.IsNull(converter.Properties);
+ }
+
+ [Test]
+ [TestCase("")]
+ [TestCase(" ")]
+ [TestCase("some string")]
+ public void Convert_Always_WriteLocalUserDataDirectory(string infix)
+ {
+ // Setup
+ string settingsDirectory = SettingsHelper.Instance.GetApplicationLocalUserSettingsDirectory(infix);
+
+ var mocks = new MockRepository();
+ var textWriter = mocks.StrictMock();
+ textWriter.Expect(w => w.Write(settingsDirectory));
+ mocks.ReplayAll();
+
+ var converter = new RiskeerUserDataFolderConverter
+ {
+ Option = infix
+ };
+
+ // Call
+ converter.Format(textWriter, null);
+
+ // Assert
+ mocks.VerifyAll();
+ }
+ }
+}
\ No newline at end of file
Index: Core/Common/test/Core.Common.Gui.Test/Commands/GuiExportHandlerTest.cs
===================================================================
diff -u -r51b64230b9b947ba32821ed104809429d469959b -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Core/Common/test/Core.Common.Gui.Test/Commands/GuiExportHandlerTest.cs (.../GuiExportHandlerTest.cs) (revision 51b64230b9b947ba32821ed104809429d469959b)
+++ Core/Common/test/Core.Common.Gui.Test/Commands/GuiExportHandlerTest.cs (.../GuiExportHandlerTest.cs) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -73,9 +73,9 @@
// Assert
string sourceTypeName = source == null ? "null" : source.GetType().FullName;
- TestHelper.AssertLogMessageIsGenerated(call, $"Ringtoets kan de huidige selectie ({sourceTypeName}) niet exporteren.");
+ TestHelper.AssertLogMessageIsGenerated(call, $"Riskeer kan de huidige selectie ({sourceTypeName}) niet exporteren.");
Assert.AreEqual("Fout", messageBoxTitle);
- Assert.AreEqual("Ringtoets kan de huidige selectie niet exporteren.", messageBoxText);
+ Assert.AreEqual("Riskeer kan de huidige selectie niet exporteren.", messageBoxText);
mockRepository.VerifyAll();
}
@@ -112,9 +112,9 @@
// Assert
string sourceTypeName = source == null ? "null" : source.GetType().FullName;
- TestHelper.AssertLogMessageIsGenerated(call, $"Ringtoets kan de huidige selectie ({sourceTypeName}) niet exporteren.");
+ TestHelper.AssertLogMessageIsGenerated(call, $"Riskeer kan de huidige selectie ({sourceTypeName}) niet exporteren.");
Assert.AreEqual("Fout", messageBoxTitle);
- Assert.AreEqual("Ringtoets kan de huidige selectie niet exporteren.", messageBoxText);
+ Assert.AreEqual("Riskeer kan de huidige selectie niet exporteren.", messageBoxText);
mockRepository.VerifyAll();
}
Index: Core/Common/test/Core.Common.Gui.Test/Core.Common.Gui.Test.csproj
===================================================================
diff -u -r9bba38e3ebe3fe261e7c97c338b016681e07c140 -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Core/Common/test/Core.Common.Gui.Test/Core.Common.Gui.Test.csproj (.../Core.Common.Gui.Test.csproj) (revision 9bba38e3ebe3fe261e7c97c338b016681e07c140)
+++ Core/Common/test/Core.Common.Gui.Test/Core.Common.Gui.Test.csproj (.../Core.Common.Gui.Test.csproj) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -41,7 +41,7 @@
-
+
Index: Core/Common/test/Core.Common.Integration.Test/Riskeer/Application.Riskeer/GuiCoreIntegrationTest.cs
===================================================================
diff -u -r51b64230b9b947ba32821ed104809429d469959b -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Core/Common/test/Core.Common.Integration.Test/Riskeer/Application.Riskeer/GuiCoreIntegrationTest.cs (.../GuiCoreIntegrationTest.cs) (revision 51b64230b9b947ba32821ed104809429d469959b)
+++ Core/Common/test/Core.Common.Integration.Test/Riskeer/Application.Riskeer/GuiCoreIntegrationTest.cs (.../GuiCoreIntegrationTest.cs) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -33,7 +33,7 @@
using Rhino.Mocks;
using Riskeer.Integration.Plugin;
-namespace Core.Common.Integration.Test.Ringtoets.Application.Ringtoets
+namespace Core.Common.Integration.Test.Riskeer.Application.Riskeer
{
[TestFixture]
public class GuiCoreIntegrationTest
Index: Core/Common/test/Core.Common.TestUtil.Test/TestHelperTest.cs
===================================================================
diff -u -r51b64230b9b947ba32821ed104809429d469959b -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Core/Common/test/Core.Common.TestUtil.Test/TestHelperTest.cs (.../TestHelperTest.cs) (revision 51b64230b9b947ba32821ed104809429d469959b)
+++ Core/Common/test/Core.Common.TestUtil.Test/TestHelperTest.cs (.../TestHelperTest.cs) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -177,7 +177,7 @@
string actualPath = TestHelper.GetScratchPadPath();
// Assert
- string expectedPath = Path.Combine(Path.GetTempPath(), "Ringtoets_Scratchpad");
+ string expectedPath = Path.Combine(Path.GetTempPath(), "Riskeer_Scratchpad");
Assert.AreEqual(expectedPath, actualPath);
Assert.IsTrue(Directory.Exists(actualPath),
$"The directory '{expectedPath}' should exist, such that unit tests have a clean environment to temporarily write files and directories to.");
@@ -193,7 +193,7 @@
string actualPath = TestHelper.GetScratchPadPath(subPath);
// Assert
- string expectedPath = Path.Combine(Path.GetTempPath(), "Ringtoets_Scratchpad", subPath);
+ string expectedPath = Path.Combine(Path.GetTempPath(), "Riskeer_Scratchpad", subPath);
Assert.AreEqual(expectedPath, actualPath);
Assert.IsFalse(File.Exists(actualPath),
$"The file '{expectedPath}' should not exist, as the folder should always be empty at the start of any unit test.");
Index: Core/Common/test/Core.Common.TestUtil/TestHelper.cs
===================================================================
diff -u -r51b64230b9b947ba32821ed104809429d469959b -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Core/Common/test/Core.Common.TestUtil/TestHelper.cs (.../TestHelper.cs) (revision 51b64230b9b947ba32821ed104809429d469959b)
+++ Core/Common/test/Core.Common.TestUtil/TestHelper.cs (.../TestHelper.cs) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -63,7 +63,7 @@
///
public static string GetScratchPadPath()
{
- string scratchPadPath = Path.Combine(Path.GetTempPath(), "Ringtoets_Scratchpad");
+ string scratchPadPath = Path.Combine(Path.GetTempPath(), "Riskeer_Scratchpad");
if (!Directory.Exists(scratchPadPath))
{
Directory.CreateDirectory(scratchPadPath);
Index: Core/Components/src/Core.Components.DotSpatial/Layer/BruTile/BruTileLayer.cs
===================================================================
diff -u -rfcc528ff894c3ef3521a3d4ec8adcda05ea5b54e -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Core/Components/src/Core.Components.DotSpatial/Layer/BruTile/BruTileLayer.cs (.../BruTileLayer.cs) (revision fcc528ff894c3ef3521a3d4ec8adcda05ea5b54e)
+++ Core/Components/src/Core.Components.DotSpatial/Layer/BruTile/BruTileLayer.cs (.../BruTileLayer.cs) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -42,7 +42,7 @@
// | Felix Obermaier | 2013.09.19 | Making deserialization work by adding AssemblyResolve event,
// | | | handler
// -------------------------------------------------------------------------------------------------------
-// Changes upon original work have been implemented to suit functional requirements for Ringtoets.
+// Changes upon original work have been implemented to suit functional requirements for Riskeer.
// These changes have been implemented as of 13 Januari 2017.
// ********************************************************************************************************
Index: Core/Common/src/Core.Common.Gui/Properties/Resources.Designer.cs
===================================================================
diff -u -r6cdb90fc3f89fe0c44b62d3be7266a0090a6b891 -r3882746b496b55f9c4ff66628a7e3f1f0fc22f81
--- Core/Common/src/Core.Common.Gui/Properties/Resources.Designer.cs (.../Resources.Designer.cs) (revision 6cdb90fc3f89fe0c44b62d3be7266a0090a6b891)
+++ Core/Common/src/Core.Common.Gui/Properties/Resources.Designer.cs (.../Resources.Designer.cs) (revision 3882746b496b55f9c4ff66628a7e3f1f0fc22f81)
@@ -759,12 +759,12 @@
}
///
/// Looks up a localized string similar to Slechts één instantie van de Ringtoets grafische interface is toegestaan per proces. Zorg ervoor dat de vorige instantie correct opgeruimd is. 'Stack trace': {0}.
///
- public static string GuiCore_Only_a_single_instance_of_Ringtoets_is_allowed_at_the_same_time_per_process_Make_sure_that_the_previous_instance_was_disposed_correctly_stack_trace_0 {
+ public static string GuiCore_Only_a_single_instance_of_Riskeer_is_allowed_at_the_same_time_per_process_Make_sure_that_the_previous_instance_was_disposed_correctly_stack_trace_0 {
get {
- return ResourceManager.GetString("GuiCore_Only_a_single_instance_of_Ringtoets_is_allowed_at_the_same_time_per_proce" +
- "ss_Make_sure_that_the_previous_instance_was_disposed_correctly_stack_trace_0", resourceCulture);
+ return ResourceManager.GetString("GuiCore_Only_a_single_instance_of_Riskeer_is_allowed_at_the_same_time_per_process" +
+ "_Make_sure_that_the_previous_instance_was_disposed_correctly_stack_trace_0", resourceCulture);
}
}
@@ -823,7 +823,7 @@
}
///
/// Looks up a localized string similar to Ringtoets kan de huidige selectie ({0}) niet exporteren..
///
public static string GuiExportHandler_GetSupportedExporterForItemUsingDialog_No_exporter_for_this_item_0_available {
get {
@@ -833,7 +833,7 @@
}
///
/// Looks up a localized string similar to Ringtoets kan de huidige selectie niet exporteren..
///
public static string GuiExportHandler_GetSupportedExporterForItemUsingDialog_No_exporter_for_this_item_available {
get {
@@ -759,12 +759,12 @@
}
///
- /// Looks up a localized string similar to Slechts één instantie van de Ringtoets grafische interface is toegestaan per proces. Zorg ervoor dat de vorige instantie correct opgeruimd is. 'Stack trace': {0}.
+ /// Looks up a localized string similar to Slechts één instantie van de Riskeer grafische interface is toegestaan per proces. Zorg ervoor dat de vorige instantie correct opgeruimd is. 'Stack trace': {0}.
///
@@ -823,7 +823,7 @@
}
///
- /// Looks up a localized string similar to Ringtoets kan de huidige selectie ({0}) niet exporteren..
+ /// Looks up a localized string similar to Riskeer kan de huidige selectie ({0}) niet exporteren..
///
public static string GuiExportHandler_GetSupportedExporterForItemUsingDialog_No_exporter_for_this_item_0_available {
@@ -833,7 +833,7 @@
}
///
- /// Looks up a localized string similar to Ringtoets kan de huidige selectie niet exporteren..
+ /// Looks up a localized string similar to Riskeer kan de huidige selectie niet exporteren..
///
public static string GuiExportHandler_GetSupportedExporterForItemUsingDialog_No_exporter_for_this_item_available {